# Generated by Django 4.2.10 on 2024-05-02 14:48

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CpuData',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('cpu_utilization', models.IntegerField(verbose_name='Утилизация ЦП, %')),
            ],
        ),
    ]
