table {
border-collapse: collapse;
width: 100%;
}

th, td {
border: 1px solid black;
padding: 8px;
text-align: center;
align: center;
}

th {
cursor: pointer;
}

#aggregate-data {
margin-top: 20px;
}
